@@ -1,9 +1,10 @@
 #' Add ggplot into a document object
 #' @param mydoc A document object
 #' @param code R code for table
+#' @param preprocessing preprocessing
 #' @param top top position of plot
 #' @return a document object
-#' @importFrom rvg ph_with_vg body_add_vg
+#' @importFrom rvg dml body_add_vg
 #' @export
 #' @examples
 #' require(rrtable)
@@ -12,16 +13,24 @@
 #' require(magrittr)
 #' code <- "ggplot(mtcars, aes(x = mpg , y = wt)) + geom_point()"
 #' read_pptx() %>% add_text(title="ggplot") %>% add_ggplot(code=code)
-add_ggplot=function(mydoc,code="",top=2){
+#' read_docx() %>% add_text(title="ggplot") %>% add_ggplot(code=code)
+add_ggplot=function(mydoc,code="",preprocessing="",top=2){
+
+
+    if(preprocessing!="") {
+           eval(parse(text=preprocessing))
+    }
+
     if(class(mydoc)=="rpptx"){
 
-            temp=paste0("ph_with_vg_at(mydoc,code=print(",code,"),left=1,top=",top,",width=8,height=5)")
+            temp=paste0("ph_with(mydoc,dml(code=print(",code,")), location = ph_location(left=1,top=",top,",width=8,height=5))")
             mydoc=eval(parse(text=temp))
 
     } else{
-        temp=paste0("body_add_vg(mydoc,code=print(",code,"))")
+        gg<-eval(parse(text=code))
+        mydoc <- mydoc %>%
+            body_add_gg(value=gg)
 
-        mydoc=eval(parse(text=temp))
     }
     mydoc
 }
