@@ -4,11 +4,11 @@
 #' @param ... Further argument to be passed to ztable
 #' @return an object of class ztable
 #' @export
-flextable2ztable=function(ft,type="html"){
+flextable2ztable=function(ft,type="html",...){
     df=ft$body$dataset
     colnames(df)=stringr::str_replace_all(colnames(df),stringr::fixed("%"),stringr::fixed("\\%"))
     colnames(df)=stringr::str_replace_all(colnames(df),stringr::fixed("\U03B2"),stringr::fixed("$\\beta$"))
-    z=ztable(df,longtable=TRUE)
+    z=ztable(df,longtable=TRUE,...)
     if(type=="latex"){
         print(z,type="latex")
     } else {z}
